@@ -33,17 +33,18 @@
 #include <QTextStream>
 #include <QVBoxLayout>
 
+#include <KIO/OpenUrlJob>
+#include <KIO/JobUiDelegate>
 #include <KGuiItem>
 #include <KIconLoader>
+#include <kio_version.h>
 #include <KIO/StatJob>
 #include <KIO/CopyJob>
 #include <KJobWidgets>
 #include <KMessageBox>
-#include <KRun>
 #include <KUrlLabel>
 
 #include "kexthighscore_internal.h"
-#include "kexthighscore.h"
 #include "kexthighscore_tab.h"
 
 
@@ -206,7 +207,9 @@ void HighscoresWidget::changeTab(int i)
 void HighscoresWidget::showURL(const QString &url)
 {
 //   kDebug(11001) ;
-    (void)new KRun(QUrl(url), this);
+    auto *job = new KIO::OpenUrlJob(QUrl(url));
+    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+    job->start();
 }
 
 void HighscoresWidget::load(int rank)
@@ -288,7 +291,11 @@ void HighscoresDialog::slotUser2()
 //   kDebug(11001) ;
     QUrl url = QFileDialog::getSaveFileUrl(this, tr("HighscoresDialog"), QUrl(), QString());
     if ( url.isEmpty() ) return;
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 69, 0)
+    auto job = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatNoDetails);
+#else
     auto job = KIO::stat(url, KIO::StatJob::SourceSide, 0);
+#endif
     KJobWidgets::setWindow(job, this);
     job->exec();
     if (!job->error()) {
